function [hist] = imhist3D(image, step, mask, min1, inter_nb1, min2, inter_nb2, min3, inter_nb3)

	set("figure_style", "new");

	image_size=size(image);

	// Read number of arguments
	[lhs,rhs] = argn(0);

	// If no step is given default value 1 is used
	if rhs==1 then
		step=1;
	end

	// If no mask given
	if rhs<=2 then
		mask=ones(image_size(1),image_size(2));
	end

	mask_size=size(mask);
	// Verify that image and Mask have the same size
	if (image_size(1)<>mask_size(1)) | (image_size(2)<>mask_size(2)) then
		disp('Image and mask should have the same size!');
		hist='err';
		return;
	end

	if rhs<=3 then
		min1=min(image(:,:,1));
		max1=max(image(:,:,1));
		min2=min(image(:,:,2));
		max2=max(image(:,:,2));
		min3=min(image(:,:,3));
		max3=max(image(:,:,3));
	end

	if (rhs>=4) & (rhs<=8)  then
		disp('Wrong number of rhs arguments!');
		hist='err';
		return;
	end

	if rhs==9 then
		max1=min1+inter_nb1*step;
		max2=min2+inter_nb2*step;
		max3=min3+inter_nb3*step;

		if size(min1,'*')<>1 then
			disp('min1 should have 1 as size!');
			hist='err';
			return;
		end
		if size(inter_nb1,'*')<>1 then
			disp('inter_nb1 should have 1 as size!');
			hist='err';
			return;
		end
		if size(min2,'*')<>1 then
			disp('min2 should have 1 as size!');
			hist='err';
			return;
		end
		if size(inter_nb2,'*')<>1 then
			disp('inter_nb2 should have 1 as size!');
			hist='err';
			return;
		end
		if size(min3,'*')<>1 then
			disp('min3 should have 1 as size!');
			hist='err';
			return;
		end
		if size(inter_nb3,'*')<>1 then
			disp('inter_nb3 should have 1 as size!');
			hist='err';
			return;
		end
	end

	if type(image)<>17 then
		disp('Input image is not a color image!');
		hist='err';
		return;
	else
		[hist_temp] = computehist3D(image(:,:,1), image(:,:,2), image(:,:,3), step, mask, min1, max1, min2, max2, min3, max3);
		hist = matrix(hist_temp, ceil((max3-min3)/step), ceil((max2-min2)/step), ceil((max1-min1)/step));
	end
endfunction
