
function [msg] = verifyperc(percentage)

	msg = ''

	if type(percentage) <> 1 | ~(and(size(percentage) == [1 1]))
		msg = "Argument ''percentage'' should be a real"
	elseif (percentage > 100) | (percentage < 0)
		msg = "Argument ''percentage'' should be between 0 and 100"
	end

endfunction

//################################################################################

function [nbFunc, msg] = verifyweigths(weights, imageNb)

	msg = ''
	nbFunc = 1

	if type(weights)<> 1
		msg = "Argument ''weights'' should be a real vector"
	elseif length(weights) <> imageNb
		msg = "There should be as many ''weights'' as computed images"
	elseif imageNb <> 1
		// Calculate the number of functions
		// The vector 'weights' can be a line vector or a column vector
		nbFunc = size(weights, 'c')
		if nbFunc == 1
			nbFunc = size(weights, 'r')
		else
			if size(weights, 'r') <> 1
				msg = "Argument ''weights'' should be a real vector"
			end
		end
	end

endfunction

//################################################################################

function [maskSize, maskDimension, mask1, msg] = verifymask(mask, imageSize, imageDimension)

	msg = ''

	if type(mask)<> 1 & type(mask)<> 17
		msg = "Argument ''mask'' should be a real (hyper)matrix"
	end

	maskSize = size(mask)
	maskDimension = size(maskSize)
	maskDimension = maskDimension(2)
	mask1 = mask

	if msg <> ''
		return
	end

	if imageDimension == 4
		if (maskDimension <> 3)
			if maskDimension <> 2  | imageSize(3) <> 1
				msg = "Argument ''mask'' should have 3 dimensions"
			else
				if ~(and(maskSize == imageSize(1:2)))
					msg = "Argument ''mask'' should have the same size that the 3 first dimensions of image "
				else
					mask1(:,:,1) = mask
					mask1 = hypermat([maskSize(1) maskSize(2) 1], mask1)
				end
			end
		else
			if ~(and(maskSize == imageSize(1:3)))
				msg = "Argument ''mask'' should have the same size that the 3 first dimensions of ''image'' "
			end
		end
	else
		if maskDimension <> imageDimension
			msg = "Arguments ''image'' and ''mask'' should have the same dimension"
		else
			if ~(and(maskSize == imageSize))
				msg = "Arguments ''image'' and ''mask'' should have the same size"
			end
		end
	end

endfunction


//################################################################################



function [imageSize, imageDimension, msg] = verifyimages(image1,image2,image3,image4,image5,image6,image7,image8,image9, image10)

	[lhs, rhs] = argn(0)

	imageSize = 0
	imageDimension = 1
	msg = ''

	msg = verifyType(image1)
 	if msg <> ''
		return
	end
	imageSize = size(image1)
	imageDimension = size(imageSize)
	imageDimension = imageDimension(2)

	if imageDimension > 4
		msg = "Image arguments should have at most four dimensions"
		return
	end

	if rhs > 1
		msg = verifyType(image2)
		if msg <> ''
			return
		end
		imageSizeTemp = size(image2)
		msg = verifySizeAndDim(imageSize, imageDimension, imageSizeTemp)
		if msg <> ''
			return
		end
	end

	if rhs > 2
		msg = verifyType(image3)
		if msg <> ''
			return
		end
		imageSizeTemp = size(image3)
		msg = verifySizeAndDim(imageSize, imageDimension, imageSizeTemp)
		if msg <> ''
			return
		end
	end

	if rhs > 3
		msg = verifyType(image4)
		if msg <> ''
			return
		end
		imageSizeTemp = size(image4)
		msg = verifySizeAndDim(imageSize, imageDimension, imageSizeTemp)
		if msg <> ''
			return
		end
	end

	if rhs > 4
		msg = verifyType(image5)
		if msg <> ''
			return
		end
		imageSizeTemp = size(image5)
		msg = verifySizeAndDim(imageSize, imageDimension, imageSizeTemp)
		if msg <> ''
			return
		end
	end

	if rhs > 5
		msg = verifyType(image6)
		if msg <> ''
			return
		end
		imageSizeTemp = size(image6)
		msg = verifySizeAndDim(imageSize, imageDimension, imageSizeTemp)
		if msg <> ''
			return
		end
	end

	if rhs > 6
		msg = verifyType(image7)
		if msg <> ''
			return
		end
		imageSizeTemp = size(image7)
		msg = verifySizeAndDim(imageSize, imageDimension, imageSizeTemp)
		if msg <> ''
			return
		end
	end

	if rhs > 7
		msg = verifyType(image8)
		if msg <> ''
			return
		end
		imageSizeTemp = size(image8)
		msg = verifySizeAndDim(imageSize, imageDimension, imageSizeTemp)
		if msg <> ''
			return
		end
	end

	if rhs > 8
		msg = verifyType(image9)
		if msg <> ''
			return
		end
		imageSizeTemp = size(image9)
		msg = verifySizeAndDim(imageSize, imageDimension, imageSizeTemp)
		if msg <> ''
			return
		end
	end

	if rhs > 9
		msg = verifyType(image10)
		if msg <> ''
			return
		end
		imageSizeTemp = size(image10)
		msg = verifySizeAndDim(imageSize, imageDimension, imageSizeTemp)
		if msg <> ''
			return
		end
	end



endfunction

//...............................................................................

function [msg] = verifySizeAndDim(imageSize, imageDimension, imageSizeTemp)

	msg = ''

	imageDimensionTemp = size(imageSizeTemp)
	imageDimensionTemp = imageDimensionTemp(2)

	if imageDimension == imageDimensionTemp
		if ~(and(imageSize == imageSizeTemp))
			msg = "Image arguments should have the same size"
		end
	else
		msg = "Image arguments should have the same dimension"
	end

endfunction

//...............................................................................

function [msg] = verifyType(image)

	msg = ''

	if type(image) <> 1
		if type(image) <> 17
			msg = "Image arguments should be real (hyper)matrix"
		else
			elem = image(1,1);
			if type(elem) <> 1
				msg = "Image arguments should be real (hyper)matrix"
			end
		end
	else
		if image == []
			msg = "Image arguments should not be empty"
		end
	end

endfunction

// ################################################################################

function [dim, msg] = verifyld(ld)

	typ = type(ld)
	dim = 0
	msg = ''

	if typ <> 1 & typ <> 17
		msg = "Argument ''learningdata'' should be a real (hyper)matrix"
	elseif ld==[]
		msg = "Argument ''learningdata'' should not be empty"
	end

	if typ == 1
		dim = 2
	elseif typ == 17
		dim = 3
	end

endfunction

// ################################################################################

function [msg] = verifync(nc)

	msg = ''

	if type(nc) <> 1 | ~(and(size(nc) == [1 1]))
		msg = "Argument ''classnb'' should be an integer"
	elseif nc <= 0
		msg = "Argument ''classnb'' should be greater than 0"
	end

endfunction


// ################################################################################

function [msg] = verifyst(st)

	msg = ''

	if type(st) <> 1 | ~(and(size(st) == [1 1]))
		msg = "Argument ''stopthreshold'' should be real"
	elseif st <= 0
		msg = "Argument ''stopthreshold'' should be greater than 0"
	end

endfunction


// ################################################################################

function [msg] = verifyinb(inb)

	msg = ''

	if type(inb) <> 1 | ~(and(size(inb) == [1 1]))
		msg = "Argument ''iterationnb'' should be real"
	elseif inb <= 0
		msg = "Argument ''iterationnb'' should be greater than 0"
	end

endfunction

// ################################################################################

function [msg] = verifyproto(prototype, nbFunc, nbComp)

	msg = ''

	if type(prototype)<> 1 & type(prototype)<> 17
		msg = "Argument ''prototype'' should be a real (hyper)matrix"
	else
		protoSize = size(prototype)
		if protoSize(1) <> nbFunc
			msg = "Argument ''prototype'' line number should equal computed images number"
		elseif nbComp > 1
			if type(prototype) == 17
				if protoSize(3) <> nbComp
					msg = "Argument ''prototype'' third dimension should equal computed images fourth dimension"
				end
			else
				msg = "Argument ''prototype'' should be a hypermatrix"
			end
		else
			if type(prototype) <> 1
				msg = "Argument ''prototype'' should be a matrix"
			end
		end
	end

endfunction

// ################################################################################

function [msg] = verifyfn(fuzzyness)

	msg = ''

	if type(fuzzyness) <> 1 | ~(and(size(fuzzyness) == [1 1]))
		msg = "Argument ''fuzzyness'' should be real"
	elseif fuzzyness <= 1
		msg = "Argument ''fuzzyness'' should be greater than 1"
	end

endfunction

// ################################################################################

function [msg] = verifyth(threshold)

	msg = ''

	if type(threshold) <> 1 | ~(and(size(threshold) == [1 1]))
		msg = "Arguments ''threshold'' should be real"
	elseif threshold < 0
		msg = "Arguments ''threshold'' should be greater than 0"
	end

endfunction


