function [results]=imshapeanalysis(image,parameters)
//shape analysis function of a labellised image
//input:
//  image: labellised image
//  parameters: characters string tab containing the parameters required
//output:
//  result model:
//  -------------
//  1	area
//  2	perimeter
//  3	compacity
//  4	xcenter
//  5	ycenter
//  6	lambda1
//  7	lambda2
//  8	theta
//  -------------
//---------------------------------------------------------------------------------------------------------------------
mode(-1);
MAX_PARAM=8;

// Read number of arguments
//-------------------------
[lhs,rhs] = argn(0);
if rhs<2 then
	disp('Wrong number of rhs arguments !');
	results='err';
	return;
end
if max(abs(image-int(image)))<>0 then
	disp('Image should be an integer one (labellized image)!');
	results='err';
	return;
end

parameters_size=size(parameters);

if parameters_size(2)<>1 then
	disp('Wrong parameters matrix!');
	results='err';
	return;
end

// To make interface easy, parameters are converted to an integer matrix
// First line : 0 if this parameter is required
// First line : 1 if this parameter is not required
// Second line : order of parameter calling
// Ex : if parameters=['perimeter';'surface'] then
// param_tab= ! 1 1 0 !
//            ! 2 1 0 !
param_tab=zeros(2,MAX_PARAM);
for i=1:size(parameters,'*')
	convstr(parameters(i),'l');
	//disp(string(parameters(i)));
	if parameters(i)=='surface' then
		param_tab(:,1)=[1;i];
	elseif parameters(i)=='perimeter' then
		param_tab(:,2)=[1;i];
	elseif parameters(i)=='compacity' then
		param_tab(:,3)=[1;i];
	elseif parameters(i)=='xcenter' then
		param_tab(:,4)=[1;i];
	elseif parameters(i)=='ycenter' then
		param_tab(:,5)=[1;i];
	elseif parameters(i)=='axis1' then
		param_tab(:,6)=[1;i];
	elseif parameters(i)=='axis2' then
		param_tab(:,7)=[1;i];
	elseif parameters(i)=='angle' then
		param_tab(:,8)=[1;i];
	elseif parameters(i)=='all' then
		param_tab=ones(2,MAX_PARAM);
		param_tab(2,:)=1:MAX_PARAM;
		parameters_size(1)=MAX_PARAM;;
	else
		disp('Wrong parameter : '+string(parameters(i))+' !');
		results='err';
		return;
	end
end

//call to C function
//------------------
if type(image)==1 then
	[results]=shape_analysis(image(:,:),param_tab(:,:),parameters_size(1),max(image)-min(image));
else
	disp('Image should have only one plan!');
	results='err';
	return;
end

endfunction
